@@ -24,6 +24,7 @@
 from .mockito import (
     when, when2, patch, expect, unstub, verify, verifyNoMoreInteractions,
     verifyZeroInteractions, verifyNoUnwantedInteractions,
+    verifyStubbedInvocationsAreUsed,
     ArgumentError)
 from . import inorder
 from .spying import spy, spy2
@@ -33,11 +34,11 @@ from .verification import VerificationError
 from .matchers import *  # noqa: F403
 from .verification import never
 
-__version__ = '1.0.2'
+__version__ = '1.0.10'
 
 __all__ = ['mock', 'spy', 'spy2', 'when', 'when2', 'patch', 'expect', 'verify',
            'verifyNoMoreInteractions', 'verifyZeroInteractions',
-           'verifyNoUnwantedInteractions',
+           'verifyNoUnwantedInteractions', 'verifyStubbedInvocationsAreUsed',
            'inorder', 'unstub',
            'VerificationError', 'ArgumentError',
            'any',       # compatibility
